@@ -1,5 +1,7 @@
 DESC = 'DESC'
 ASC = 'ASC'
+AND = 'AND'
+OR = 'OR'
 
 ORDER_BY_PARAMS = [
     ASC,
@@ -9,12 +11,21 @@ ORDER_BY_PARAMS = [
 WHERE_OPTS = [
     "<", "<<", "<=",
     ">=", ">>", ">",
-    "=", "==", "!=", "<>"
+    "=", "==", "!=", "<>",
+    "IN", "LIKE"
+]
+
+WHERE_CONDITIONS = [
+    AND,
+    OR
 ]
 
 __all__ = [
     'DESC',
     'ASC',
+    'AND',
+    'OR',
     'ORDER_BY_PARAMS',
-    'WHERE_OPTS'
+    'WHERE_OPTS',
+    'WHERE_CONDITIONS'
 ]
